.. _components:

Overview
=====================

This is the summary of the available ``earthkit`` components.

.. list-table::
    :widths: 20 65 15
    :header-rows: 1

    * - Component
      - Description
      - Logo
    * - :xref:`earthkit-data`
      - Format-agnostic Python interface for geospatial data with a focus on meteorology and climate science.
      - .. image:: https://raw.githubusercontent.com/ecmwf/earthkit-data/main/docs/_static/earthkit-data.png
          :width: 120px
    * - :xref:`earthkit-geo`
      - Geospatial computations
      -
    * - :xref:`earthkit-meteo`
      - Meteorological computations.
      -
    * - :xref:`earthkit-plots`
      - Visualisation tools and templates
      -
    * - :xref:`earthkit-regrid`
      - Regridding of geospatial data.
      -
    * - :xref:`earthkit-transforms`
      - Aggregation and transformation of geospatial data.
      -
